Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/neopixel_simpletest.py
    :caption: examples/neopixel_simpletest.py
    :linenos:

RPI simple test
---------------

Test using the Raspberry Pi.

.. literalinclude:: ../examples/neopixel_rpi_simpletest.py
    :caption: examples/neopixel_rpi_simpletest.py
    :linenos:

Pixel
-----

Example of setting the color of a single pixel.

.. literalinclude:: ../examples/neopixel_pixel.py
    :caption: examples/neopixel_pixel.py
    :linenos:

Rainbow
-------

Example of cycling through the colors of the rainbow.

.. literalinclude:: ../examples/neopixel_rainbowio_simpletest.py
    :caption: examples/neopixel_rainbowio_simpletest.py
    :linenos:

Bouncing ball
-------------

Example of a bouncing ball animation.

.. literalinclude:: ../examples/neopixel_bouncing_ball.py
    :caption: examples/neopixel_bouncing_ball.py
    :linenos:
